@@ -9,12 +9,13 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.0.51b"
+#define MYSQL_SERVER_VERSION		"5.0.67"
 #define MYSQL_BASE_VERSION		"mysqld-5.0"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50051
+#define MYSQL_VERSION_ID		50067
 #define MYSQL_PORT			3306
+#define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/var/run/mysql/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
 #define MYSQL_COMPILATION_COMMENT	"Source distribution"
